import React from 'react';
import {
  DrawerForm,
  ProFormText,
  ProFormSelect,
  ProFormDigit,
  ProFormList
} from '@ant-design/pro-components';
import { Form, Row, Col } from 'antd';
import WangEditor from '@/components/Wangeditor';
import { postTaCheckItemQu } from '@/service/tdlocquestion';

export default (props) => {
  const {open, onOpenChange, quInfo, itemId, onChange} = props;
  const [form] = Form.useForm();
  
  const onFinish = async (values) => {
    const data = {
      ...(quInfo || {}),
      ...values,
      itemId,
    }

    const res = await postTaCheckItemQu(data).then(x => x);

    onChange(res);
    return true;
  }

  React.useEffect(() => {
    if (quInfo) {
      form.setFieldsValue(quInfo);
    } else {
      form.resetFields();
    }
  }, [quInfo]);

  return (
    <DrawerForm
      title="问题维护"
      open={open}
      width={800}
      form={form}
      destroyOnClose
      onFinish={onFinish}
      onOpenChange={onOpenChange}
    >
      <Row gutter={24}>
        <Col span={6}>
          <ProFormText
            name="sortNo"
            label="序号"
            placeholder="请填写"
            rules={[
              {
                required: true,
                message: '请填写序号',
              },
            ]}
          />
        </Col>
        <Col span={18}>
          <ProFormText
            name="title"
            label="题干描述"
            placeholder="请填写"
            rules={[
              {
                required: true,
                message: '请填写题干',
              },
            ]}
          />
        </Col>
      </Row>
      <Row gutter={24}>
        <Col span={12}>
          <ProFormSelect
            name="quType"
            label="问题类型"
            fieldProps={{
              style: { width: '100%' }
            }}
            valueEnum={{
              radio: '单选',
              fill: '填空'
            }}
            rules={[
              {
                required: true,
                message: '请选择问题类型',
              },
            ]}
          />
        </Col>
        <Col span={12}>
          <ProFormSelect
            name="computeType"
            label="计分方式"
            fieldProps={{
              style: { width: '100%' }
            }}
            valueEnum={{
              '+': '得分',
              '-': '扣分'
            }}
            rules={[
              {
                required: true,
                message: '请选择计分方式',
              },
            ]}
          />
        </Col>
      </Row>
      <Row gutter={24}>
        <Col span={12}>
          <ProFormDigit
            name="maxScore"
            label="最 高 分"
            min={0}
            fieldProps={{ precision: 2 }}
            rules={[
              {
                required: true,
                message: '请设置最高分',
              },
            ]}
          />
        </Col>
        <Col span={12}>
          <ProFormDigit
            name="anScore"
            label="单项计分"
            min={0}
            fieldProps={{ precision: 2 }}
            rules={[
              {
                required: true,
                message: '请设置单项计分',
              },
            ]}
          />
        </Col>
      </Row>
      <Form.Item name="stand" label="评分标准">
        <WangEditor
          height="200px"
          toolbarConfig={{
            toolbarKeys: [
              'headerSelect',
              'blockquote',
              '|',
              'bold',
              'underline',
              'italic',
              'color',
              'fontSize',
              '|',
              'bulletedList',
              'numberedList',
            ]
          }}
        />
      </Form.Item>
      <ProFormList
        name="answerList"
        label="选项列表"
        copyIconProps={false}
      >
        <Row gutter={24} style={{width: '730px'}}>
          <Col span={6}>
            <ProFormText
              name="answerCode"
              label="选项"
              help="类似 A, B, C, D"
            />
          </Col>
          <Col span={6}>
            <ProFormDigit
              name="score"
              label="计分"
              min={0}
              fieldProps={{ precision: 2 }}
            />
          </Col>
          <Col span={12}>
            <ProFormText
              name="answer"
              label="答案"
              placeholder="具体选项内容"
            />
          </Col>
        </Row>
      </ProFormList>
    </DrawerForm>
  )
}
