import React from 'react';
import { Button, Form, Row, Col, Card, List, Popconfirm } from 'antd';
import QuForm from './QuForm';
import { postTaCheckItemQu, getTaCheckItemQu } from '@/service/tdlocquestion';
import { deleteTaCheckItemQu } from '@/service/tacheckitemqu';
import { message } from 'antd';

const QuItem = (props) => {
  const { qu, onEdit, onDelete } = props;

  const quTitle = `${qu?.sortNo}. [${qu?.quType == 'fill' ? '填空' : '选择'}] ${qu?.title} (分值: ${qu?.computeType} ${qu?.anScore}/${qu?.maxScore})`

  return (
    <Card
      title={quTitle} 
      style={{marginTop: '24px'}}
      extra={(
        <>
          <Button type='link' onClick={onEdit}>修改</Button>
          <Popconfirm
            title="确认进行删除操作?"
            onConfirm={onDelete}
          >
            <Button type='link' danger >删除</Button>
          </Popconfirm>
        </>
      )} 
    >
      <Card.Meta
        title={
          qu?.quType != 'fill' ?
          (
            <Row gutter={24}>
              {
                (qu?.answerList||[]).map((item) => {
                  const anStr = `${item.answerCode}. (${item.score || 0}分) ${item.answer}`;

                  return (
                    <Col span={12} key={item.answerId} style={{ height: '32px', lineHeight: '32px', fontWeight: 400 }}>
                    {anStr}
                    </Col>
                  );
                })
              }
            </Row>
          ) : null
        }
        description={(
          <>
            <h3>验收标准</h3>
            <div dangerouslySetInnerHTML={{ __html: qu?.stand }} />
          </>
        )}
      />
    </Card>
  );
}

export default React.forwardRef((props, ref) => {

  const { itemId, onChange } = props;
  
  const [open, setOpen] = React.useState(false);
  const [quInfo, setQuInfo] = React.useState(false);
  const [list, setList] = React.useState([]);

  const onFinish = (res) => {
    let found = false;
    const newList = list.map(item => {
      if (item.quId === res.quId) {
        found = true;
        return res;
      } else {
        return item
      }
    });

    if (!found) {
      newList.push(res);
    }

    setList(list);
  }

  const onEditQu = (qu) => {
    setQuInfo(qu);
    setOpen(true);
  }

  const onDeleteQu = (qu) => {
    if (qu?.quId) {
      deleteTaCheckItemQu(qu.quId).then(() => {
        setList(list.filter(x => x.quId !== qu.quId));
      })
    } else {
      setList(list.filter(x => x.quId !== qu.quId));
    }
  }

  React.useEffect(() => {
    if (itemId) {
      getTaCheckItemQu({pageSize: 500, itemId}).then((res) => {
        setList(res.records);
      });
    }
  }, [itemId]);

  React.useImperativeHandle(ref, () => ({
    add: () => {
      setQuInfo();
      setOpen(true);
    },
  }), []);

  return (
    <>
      <QuForm itemId={itemId} quInfo={quInfo} open={open} onOpenChange={setOpen} onChange={onFinish} />
      <List
        itemLayout="horizontal"
        dataSource={list}
        renderItem={(item) => (
          <QuItem
            qu={item}
            onEdit={() => onEditQu(item)}
            onDelete={() => onDeleteQu(item)}
          />
        )}
      />
    </>
  )
});
